import { motion } from 'framer-motion';
import { Code, Database, Cloud, Smartphone, Lightbulb, Users, Award, MapPin, Calendar, Mail, Github, Linkedin, Twitter } from 'lucide-react';

const stats = [
  { label: 'Years of Experience', value: '1.5+' },
  { label: 'Projects Completed', value: '5+' },
  { label: 'Technologies Mastered', value: '15+' },
  { label: 'Coffee Consumed', value: '∞' }
];

const experiences = [
    {
    title: 'GirlScript Summer Of Code 2025 (GSSoC25)',
    company: 'Various Projects',
    period: 'July,2025 - Present',
    location: 'Remote',
    description: 'Actively contributing to open source projects, focusing on improving developer tooling, documentation, and accessibility. Collaborate with global teams to deliver impactful solutions and mentor new contributors.',
    achievements: [
      'Contributed to repositories across React, TypeScript, and DevOps ecosystems',
      'Authored and maintained several npm packages with 1k+ weekly downloads',
      'Reviewed and merged pull requests, ensuring code quality and best practices',
      'Organized and led community workshops on open source contribution'
    ]
  },
  {
    title: 'Software Development Intern',
    company: 'Prodigy InfoTech',
    period: '1st July, 2025 - August',
    location: 'Remote',
    description: 'Completed a rigorous software development internship at PRODIGY InfoTech, building five Python applications of increasing complexity from basic utilities to advanced algorithmic solutions.',
    achievements: [
      ' Built 5 complete applications with both GUI and CLI interfaces.',
      ' Implemented comprehensive testing with 100% core functionality coverage.',
      ' Applied OOP principles and advanced algorithms (backtracking, optimization).',
      ' Designed intuitive user interfaces with real-time feedback.',
      ' Developed projects ranging from temperature converters to web scrapers.',
      ' Demonstrated progression in programming complexity and technical skills.',
    ]
  },
    {
    title: 'Open Source Contributor',
    company: 'Various Projects',
    period: '2024 - Present',
    location: 'Remote',
    description: 'Actively contributing to open source projects, focusing on improving developer tooling, documentation, and accessibility. Collaborate with global teams to deliver impactful solutions and mentor new contributors.',
    achievements: [
      'Contributed to repositories across React, TypeScript, and DevOps ecosystems',
      'Authored and maintained several npm packages with 1k+ weekly downloads',
      'Reviewed and merged pull requests, ensuring code quality and best practices',
      'Organized and led community workshops on open source contribution'
    ]
  },
  {
    title: 'Freelance Full-Stack Developer',
    company: 'Self-Employed',
    period: '2023 - Present',
    location: 'Remote • Global',
    description: 'Providing end-to-end web development services to clients worldwide, specializing in modern React applications, backend APIs, and cloud deployment solutions. Building scalable applications across various industries.',
    achievements: [
      'Delivered 5+ successful projects for clients across US, Europe, and Asia',
      'Maintained  rating on Upwork and Fiverr with 100% job success rate',
      'Built custom e-commerce platforms generating $2M+ in client revenue',
      'Reduced client operational costs by 60% through automation and optimization',
      'Created reusable component libraries saving 30+ hours per project',
      'Established long-term partnerships with  recurring enterprise clients',

    ]
  },
  // {
  //   title: 'Open Source Contributor',
  //   company: 'Various Projects',
  //   period: '2024 - Present',
  //   location: 'Remote',
  //   description: 'Actively contributing to open source projects, focusing on improving developer tooling, documentation, and accessibility. Collaborate with global teams to deliver impactful solutions and mentor new contributors.',
  //   achievements: [
  //     'Contributed to repositories across React, TypeScript, and DevOps ecosystems',
  //     'Authored and maintained several npm packages with 1k+ weekly downloads',
  //     'Reviewed and merged pull requests, ensuring code quality and best practices',
  //     'Organized and led community workshops on open source contribution'
  //   ]
  // },
  // {
  //   title: 'Frontend Developer',
  //   company: 'StartupTech',
  //   period: '2019 - 2020',
  //   location: 'On-site',
  //   description: 'Focused on creating intuitive user interfaces and exceptional user experiences. Worked closely with designers to implement pixel-perfect designs.',
  //   achievements: [
  //     'Increased user engagement by 35% through UI/UX improvements',
  //     'Reduced development time by 25% using component libraries',
  //     'Mentored 2 junior developers in modern frontend practices'
  //   ]
  // }
];

const skills = [
  {
    category: 'Frontend Development',
    icon: <Code className="w-6 h-6" />,
    technologies: ['React', 'TypeScript', 'Vue.js', 'Tailwind CSS', 'Framer Motion']
  },
  {
    category: 'Backend Development',
    icon: <Database className="w-6 h-6" />,
    technologies: ['Node.js', 'Python', 'Express.js', 'FastAPI', 'PostgreSQL', 'MongoDB']
  },
  {
    category: 'Cloud & DevOps',
    icon: <Cloud className="w-6 h-6" />,
    technologies: ['AWS', 'Azure', 'Docker', 'Kubernetes', 'CI/CD', 'Terraform']
  },
  {
    category: 'Mobile Development(freelance)',
    icon: <Smartphone className="w-6 h-6" />,
    technologies: ['React Native', 'iOS', 'Android', 'Firebase']
  },
  {
    category: 'AI & Machine Learning(learning)',
    icon: <Smartphone className="w-6 h-6" />,
    technologies: ['TensorFlow', 'PyTorch', 'scikit-learn', 'Keras', 'Natural Language Processing']
  }
];

const values = [
  {
    icon: <Lightbulb className="w-8 h-8" />,
    title: 'Innovation',
    description: 'Always exploring new technologies and creative solutions to complex problems.'
  },
  {
    icon: <Users className="w-8 h-8" />,
    title: 'Collaboration',
    description: 'Believing in the power of teamwork and knowledge sharing to achieve greatness.'
  },
  {
    icon: <Award className="w-8 h-8" />,
    title: 'Excellence',
    description: 'Committed to delivering high-quality code and exceptional user experiences.'
  }
];

export default function About() {
  return (
    <div className="min-h-screen bg-white dark:bg-gray-900">
      {/* Hero Section */}
      <section className="py-20 bg-gradient-to-r from-blue-900 to-cyan-600">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
            <motion.div
              initial={{ opacity: 0, x: -50 }}
              animate={{ opacity: 1, x: 0 }}
              transition={{ duration: 0.6 }}
            >
              <h1 className="text-5xl font-heading font-bold text-white mb-6">
                About Mohit Suthar
              </h1>
              <p className="text-xl text-gray-100 mb-8 leading-relaxed">
                A passionate Full-Stack Software Developer with 1.5+ years of experience
                crafting digital solutions that make a difference. I specialize in building
                scalable applications using modern technologies and best practices.
              </p>
              <div className="flex items-center space-x-6 text-gray-100">
                <div className="flex items-center">
                  <MapPin className="w-5 h-5 mr-2" />
                  <span>Remote • Global</span>
                </div>
                <div className="flex items-center">
                  <Calendar className="w-5 h-5 mr-2" />
                  <span>Available for Projects</span>
                </div>
              </div>
            </motion.div>

            <motion.div
              initial={{ opacity: 0, x: 50 }}
              animate={{ opacity: 1, x: 0 }}
              transition={{ duration: 0.6, delay: 0.2 }}
              className="flex justify-center"
            >              <div className="relative group">
                {/* 3D Container with Advanced Effects */}
                <div className="relative w-80 h-96 perspective-1000">
                  {/* Gradient Background Glow Effects */}
                  <div className="absolute inset-0 bg-gradient-to-br from-blue-500/20 via-purple-500/20 to-cyan-500/20 rounded-3xl transform rotate-3 group-hover:rotate-6 transition-all duration-700 ease-out blur-lg"></div>
                  <div className="absolute inset-0 bg-gradient-to-tr from-orange-400/30 via-pink-500/30 to-blue-500/30 rounded-3xl transform -rotate-3 group-hover:-rotate-6 transition-all duration-700 ease-out blur-lg"></div>

                  {/* Professional Image - No Background Card */}
                  <div className="relative w-full h-full transform group-hover:scale-105 group-hover:rotate-y-12 transition-all duration-700 ease-out" style={{ transformStyle: 'preserve-3d' }}>
                    <img
                      src="/professional-image.jpg"
                      alt="Mohit Suthar - Full-Stack Developer"
                      className="w-full h-full object-cover rounded-3xl shadow-2xl transform group-hover:scale-110 transition-all duration-700 ease-out filter group-hover:brightness-110"
                      onError={(e) => {
                        // Fallback to MS text if image doesn't load
                        const target = e.currentTarget as HTMLImageElement;
                        target.style.display = 'none';
                        const fallback = target.nextElementSibling as HTMLElement;
                        if (fallback) {
                          fallback.style.display = 'flex';
                        }
                      }}
                      onLoad={(e) => {
                        // Hide fallback if image loads successfully
                        const target = e.currentTarget as HTMLImageElement;
                        const fallback = target.nextElementSibling as HTMLElement;
                        if (fallback) {
                          fallback.style.display = 'none';
                        }
                      }}
                    />

                    {/* Fallback MS Text (shown if image fails to load) */}
                    <div className="absolute inset-0 flex items-center justify-center bg-gradient-to-br from-blue-600 to-cyan-600 rounded-3xl shadow-2xl">
                      <span className="text-6xl font-bold text-white">MS</span>
                    </div>

                    {/* 3D Highlight Effect on Image */}
                    <div className="absolute inset-0 bg-gradient-to-br from-white/30 via-transparent to-transparent rounded-3xl opacity-0 group-hover:opacity-100 transition-opacity duration-500"></div>

                    {/* Gloss Effect on Image */}
                    <div className="absolute top-0 left-0 right-0 h-1/3 bg-gradient-to-b from-white/20 to-transparent rounded-t-3xl opacity-0 group-hover:opacity-100 transition-opacity duration-500"></div>

                    {/* Animated Border Glow Around Image */}
                    <div className="absolute inset-0 rounded-3xl border-2 border-gradient-to-r from-cyan-400/60 via-blue-500/60 to-purple-500/60 opacity-0 group-hover:opacity-100 transition-all duration-500 shadow-lg shadow-blue-500/25"></div>
                  </div>

                  {/* 3D Floating Elements */}
                  <div className="absolute -top-6 -left-6 w-12 h-12 bg-gradient-to-br from-cyan-400 to-blue-500 rounded-2xl shadow-2xl animate-float transform group-hover:scale-125 group-hover:-translate-y-3 transition-all duration-700 flex items-center justify-center">
                    <Code className="w-6 h-6 text-white" />
                  </div>
                  <div className="absolute -top-4 -right-8 w-10 h-10 bg-gradient-to-br from-purple-400 to-pink-500 rounded-xl shadow-2xl animate-float-delayed transform group-hover:scale-125 group-hover:-translate-y-2 transition-all duration-700 flex items-center justify-center">
                    <span className="text-white font-bold text-sm">JS</span>
                  </div>
                  <div className="absolute -bottom-6 -right-4 w-8 h-8 bg-gradient-to-br from-orange-400 to-red-500 rounded-lg shadow-xl animate-pulse transform group-hover:scale-150 group-hover:translate-y-1 transition-all duration-500"></div>

                  {/* Enhanced 3D Shadow */}
                  <div className="absolute -bottom-8 left-1/2 transform -translate-x-1/2 w-72 h-20 bg-gradient-to-r from-transparent via-black/30 to-transparent rounded-full blur-2xl group-hover:scale-125 group-hover:bg-gradient-to-r group-hover:from-transparent group-hover:via-black/40 group-hover:to-transparent transition-all duration-700"></div>

                  {/* Multiple Shadow Layers for Depth */}
                  <div className="absolute -bottom-4 left-1/2 transform -translate-x-1/2 w-64 h-12 bg-blue-500/20 rounded-full blur-xl group-hover:scale-110 transition-all duration-500"></div>
                </div>

                {/* Professional Badge with 3D Effect */}
                <div className="absolute -bottom-6 -right-6 bg-gradient-to-br from-white via-gray-50 to-gray-100 dark:from-gray-800 dark:via-gray-700 dark:to-gray-900 rounded-2xl p-4 shadow-2xl border border-gray-200 dark:border-gray-600 transform group-hover:scale-110 group-hover:rotate-12 transition-all duration-500 ease-out">
                  <div className="relative">
                    <Database className="w-8 h-8 text-blue-600 dark:text-cyan-400 relative z-10" />
                    {/* Badge Glow Effect */}
                    <div className="absolute inset-0 bg-blue-500/20 dark:bg-cyan-400/20 rounded-2xl blur-md group-hover:scale-150 transition-all duration-500"></div>
                  </div>
                </div>

                {/* Status Indicator */}
                <div className="absolute top-6 right-6 flex items-center space-x-2 bg-green-500/90 backdrop-blur-sm rounded-2xl px-4 py-2 shadow-lg transform group-hover:scale-105 transition-all duration-300">
                  <div className="w-2 h-2 bg-white rounded-full animate-pulse"></div>
                  <span className="text-white text-sm font-medium">Available</span>
                </div>
              </div>
            </motion.div>
          </div>
        </div>
      </section>

      {/* Stats Section */}
      <section className="py-16 bg-gray-50 dark:bg-gray-800">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid grid-cols-2 md:grid-cols-4 gap-8">
            {stats.map((stat, index) => (
              <motion.div
                key={stat.label}
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.6, delay: index * 0.1 }}
                className="text-center"
              >
                <div className="text-4xl font-bold text-blue-600 dark:text-cyan-400 mb-2">
                  {stat.value}
                </div>
                <div className="text-gray-600 dark:text-gray-300 font-medium">
                  {stat.label}
                </div>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* Experience Section */}
      <section className="py-20">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            className="text-center mb-16"
          >
            <h2 className="text-4xl font-heading font-bold text-gray-900 dark:text-white mb-4">
              Professional Journey
            </h2>
            <p className="text-xl text-gray-600 dark:text-gray-300 max-w-3xl mx-auto">
              A timeline of growth, learning, and impact across different organizations and projects.
            </p>
          </motion.div>

          <div className="space-y-12">
            {experiences.map((exp, index) => (
              <motion.div
                key={index}
                initial={{ opacity: 0, x: index % 2 === 0 ? -50 : 50 }}
                animate={{ opacity: 1, x: 0 }}
                transition={{ duration: 0.6, delay: index * 0.2 }}
                className="bg-white dark:bg-gray-800 rounded-lg shadow-lg p-8"
              >
                <div className="flex flex-col md:flex-row md:items-start md:justify-between mb-6">
                  <div>
                    <h3 className="text-2xl font-heading font-bold text-gray-900 dark:text-white mb-2">
                      {exp.title}
                    </h3>
                    <p className="text-lg text-blue-600 dark:text-cyan-400 font-semibold mb-1">
                      {exp.company}
                    </p>
                    <div className="flex items-center text-gray-600 dark:text-gray-300 space-x-4">
                      <span>{exp.period}</span>
                      <span>•</span>
                      <span>{exp.location}</span>
                    </div>
                  </div>
                </div>

                <p className="text-gray-700 dark:text-gray-300 mb-6 leading-relaxed">
                  {exp.description}
                </p>

                <div>
                  <h4 className="font-semibold text-gray-900 dark:text-white mb-3">
                    Key Achievements:
                  </h4>
                  <ul className="space-y-2">
                    {exp.achievements.map((achievement, i) => (
                      <li key={i} className="flex items-start">
                        <div className="w-2 h-2 bg-orange-500 rounded-full mt-2 mr-3 flex-shrink-0"></div>
                        <span className="text-gray-700 dark:text-gray-300">
                          {achievement}
                        </span>
                      </li>
                    ))}
                  </ul>
                </div>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* Skills Section */}
      <section className="py-20 bg-gray-50 dark:bg-gray-800">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">          <motion.div
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.6 }}
          className="text-center mb-16"
        >
          <h2 className="text-3xl md:text-4xl font-heading font-bold text-gray-900 dark:text-white mb-4">
            Technical Expertise
          </h2>
          <p className="text-lg md:text-xl text-gray-600 dark:text-gray-300 max-w-3xl mx-auto leading-relaxed">
            A comprehensive toolkit of modern technologies and frameworks for building exceptional digital experiences.
          </p>
        </motion.div><div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
            {skills.map((skill, index) => (
              <motion.div
                key={skill.category}
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.6, delay: index * 0.1 }}
                className="bg-white dark:bg-gray-900 rounded-xl p-6 shadow-lg hover:shadow-xl transition-all duration-300 border border-gray-100 dark:border-gray-700 group"
              >
                <div className="flex items-center mb-4">
                  <div className="p-3 bg-blue-100 dark:bg-blue-900 rounded-xl text-blue-600 dark:text-cyan-400 mr-3 group-hover:scale-110 transition-transform duration-300">
                    {skill.icon}
                  </div>
                  <h3 className="font-heading font-semibold text-lg text-gray-900 dark:text-white group-hover:text-primary-600 dark:group-hover:text-primary-400 transition-colors duration-300">
                    {skill.category}
                  </h3>
                </div>
                <div className="flex flex-wrap gap-2">
                  {skill.technologies.map((tech) => (
                    <span
                      key={tech}
                      className="px-3 py-1.5 bg-gray-100 dark:bg-gray-700 text-gray-700 dark:text-gray-300 rounded-lg text-sm font-medium hover:bg-primary-100 dark:hover:bg-primary-900 hover:text-primary-700 dark:hover:text-primary-300 transition-all duration-200 cursor-default"
                    >
                      {tech}
                    </span>
                  ))}
                </div>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* Values Section */}
      <section className="py-20">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            className="text-center mb-16"
          >
            <h2 className="text-4xl font-heading font-bold text-gray-900 dark:text-white mb-4">
              Core Values
            </h2>
            <p className="text-xl text-gray-600 dark:text-gray-300 max-w-3xl mx-auto">
              The principles that guide my approach to development and collaboration.
            </p>
          </motion.div>

          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            {values.map((value, index) => (
              <motion.div
                key={value.title}
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.6, delay: index * 0.2 }}
                className="text-center p-8 bg-white dark:bg-gray-800 rounded-lg shadow-lg"
              >
                <div className="inline-flex items-center justify-center w-16 h-16 bg-gradient-to-r from-blue-600 to-cyan-600 text-white rounded-full mb-6">
                  {value.icon}
                </div>
                <h3 className="text-xl font-heading font-bold text-gray-900 dark:text-white mb-4">
                  {value.title}
                </h3>
                <p className="text-gray-600 dark:text-gray-300 leading-relaxed">
                  {value.description}
                </p>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* Contact CTA */}
      <section className="py-20 bg-gradient-to-r from-blue-900 to-cyan-600">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
          >
            <h2 className="text-4xl font-heading font-bold text-white mb-6">
              Let's Build Something Amazing Together
            </h2>
            <p className="text-xl text-gray-100 mb-8 max-w-3xl mx-auto">
              Ready to bring your ideas to life? I'm always excited to work on new projects
              and collaborate with fellow innovators.
            </p>

            <div className="flex flex-col sm:flex-row items-center justify-center space-y-4 sm:space-y-0 sm:space-x-6 mb-8">
              <a
                href="mailto:kingmohitsuthar@gmail.com"
                className="flex items-center px-8 py-4 bg-orange-500 hover:bg-orange-600 text-white rounded-lg font-semibold transition-colors duration-200"
              >
                <Mail className="w-5 h-5 mr-2" />
                Get In Touch
              </a>

              <div className="flex items-center space-x-4">
                <a
                  href="https://github.com/MohitSutharOfficial"
                  target="_blank"
                  rel="noopener noreferrer"
                  className="p-3 bg-white/10 hover:bg-white/20 text-white rounded-full transition-colors duration-200"
                >
                  <Github className="w-6 h-6" />
                </a>
                <a
                  href="https://www.linkedin.com/in/mohit-suthar-4136a52a6/"
                  target="_blank"
                  rel="noopener noreferrer"
                  className="p-3 bg-white/10 hover:bg-white/20 text-white rounded-full transition-colors duration-200"
                >
                  <Linkedin className="w-6 h-6" />
                </a>
                <a
                  href="https://x.com/OfficialMsuthar"
                  target="_blank"
                  rel="noopener noreferrer"
                  className="p-3 bg-white/10 hover:bg-white/20 text-white rounded-full transition-colors duration-200"
                >
                  <Twitter className="w-6 h-6" />
                </a>
              </div>
            </div>
          </motion.div>
        </div>
      </section>
    </div>
  );
}
